@@ -16,12 +16,16 @@ or that the previous query resulted in a communication error.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-devices"
-__date__ = "15-07-2020"
-__version__ = "0.2.1"
+__date__ = "14-09-2022"
+__version__ = "1.0.0"
 # pylint: disable=try-except-raise
 
 import time
-import visa
+
+# TODO: Current demanded requirement pyvisa~=1.11 was ~=1.9 before. 1.11 has
+# broken backwards comp. Still need to test if all is still fine. Delete this
+# comment if tested okay.
+import pyvisa
 import numpy as np
 
 from dvg_debug_functions import print_fancy_traceback
@@ -157,7 +161,7 @@ class Keysight_3497xA:
     # --------------------------------------------------------------------------
 
     def close(self):
-        if not self.is_alive:
+        if (not self.is_alive) or (self.device is None):
             # print("ERROR: Device is already closed.")
             pass  # Remain silent. Device is already closed.
         else:
@@ -174,7 +178,7 @@ class Keysight_3497xA:
         and its identity is queried and stored in '_idn'.
 
         Args:
-            rm: Instance of visa.ResourceManager
+            rm: Instance of pyvisa.ResourceManager
 
         Returns: True if successful, False otherwise.
         """
@@ -187,7 +191,7 @@ class Keysight_3497xA:
                 self._visa_address, timeout=VISA_TIMEOUT
             )
             self.device.clear()
-        except visa.VisaIOError:
+        except pyvisa.VisaIOError:
             print("Could not open resource.\n")
             return False
         except:
@@ -278,7 +282,7 @@ class Keysight_3497xA:
 
         try:
             self.device.write(msg_str)
-        except visa.VisaIOError as err:
+        except pyvisa.VisaIOError as err:
             # Print error and struggle on
             print_fancy_traceback(err, 3)
             return False
@@ -311,7 +315,7 @@ class Keysight_3497xA:
         else:
             try:
                 ans_str = self.device.query(msg_str)
-            except visa.VisaIOError as err:
+            except pyvisa.VisaIOError as err:
                 # Print error and struggle on
                 print_fancy_traceback(err, 3)
             except:
@@ -320,7 +324,7 @@ class Keysight_3497xA:
                 ans_str = ans_str.strip()
                 success = True
 
-        return (success, ans_str)
+        return success, ans_str
 
     # --------------------------------------------------------------------------
     #   query_ascii_values
@@ -346,7 +350,7 @@ class Keysight_3497xA:
         else:
             try:
                 ans_list = self.device.query_ascii_values(msg_str)
-            except visa.VisaIOError as err:
+            except pyvisa.VisaIOError as err:
                 # Print error and struggle on
                 print_fancy_traceback(err, 3)
             except:
@@ -354,7 +358,7 @@ class Keysight_3497xA:
             else:
                 success = True
 
-        return (success, ans_list)
+        return success, ans_list
 
     # --------------------------------------------------------------------------
     #   query_diagnostics
@@ -501,8 +505,7 @@ class Keysight_3497xA:
 
         # The reset operation can take a long time to complete. Momentarily
         # increase the timeout to 2000 msec if necessary.
-        if self.device.timeout < 2000:
-            self.device.timeout = 2000
+        self.device.timeout = max(self.device.timeout, 2000)
 
         # Send clear and reset
         success = self.write("abor;*rst;*cls")
